@@ -20,26 +20,28 @@ window.addEventListener("load", () => {
             form.querySelectorAll(".textfield")
                 .forEach(textfield => {
                     let input = textfield.querySelector("input");
-                    input.addEventListener("invalid", e => {
-                        e.preventDefault();
-                        let old_helper_text = textfield.querySelector(".textfield__helper-text");
-                        if (old_helper_text !== null) {
-                            old_helper_text.remove();
-                        }
-                        let helper_text = document.createElement("div");
-                        helper_text.classList.add("view", "text", "text--caption", "textfield__helper-text");
-                        helper_text.textContent = "Ce champs doit être rempli";
-                        textfield.appendChild(helper_text);
-                        textfield.classList.add("textfield--error");
-                        input.addEventListener("input", () => {
-                            textfield.classList.remove("textfield--error");
+                    if (input) {
+                        input.addEventListener("invalid", e => {
+                            e.preventDefault();
+                            let old_helper_text = textfield.querySelector(".textfield__helper-text");
                             if (old_helper_text !== null) {
-                                helper_text.replaceWith(old_helper_text);
-                            } else {
-                                helper_text.remove();
+                                old_helper_text.remove();
                             }
-                        }, {once: true});
-                    });
+                            let helper_text = document.createElement("div");
+                            helper_text.classList.add("view", "text", "text--caption", "textfield__helper-text");
+                            helper_text.textContent = "Ce champs doit être rempli";
+                            textfield.appendChild(helper_text);
+                            textfield.classList.add("textfield--error");
+                            input.addEventListener("input", () => {
+                                textfield.classList.remove("textfield--error");
+                                if (old_helper_text !== null) {
+                                    helper_text.replaceWith(old_helper_text);
+                                } else {
+                                    helper_text.remove();
+                                }
+                            }, {once: true});
+                        });
+                    }
                 });
             form.querySelectorAll("[data-auto-submit]")
                 .forEach(input => {
